@@ -62,9 +62,7 @@ binomial.fit.robmixglm <- function(x,y,offset,gh,notrials,EMTol,  calcHessian=TR
       if (is.null(starting.values)) {
         
         
-        if (dim(x)[2] == 1) robust.binomial.prefit <- glm(cbind(y[,1],y[,2])~1,family=binomial(), offset=offset,
-                                                          subset=(outliers!=1))
-        else robust.binomial.prefit <- glm(cbind(y[,1],y[,2])~x[,colnames(x)!="(Intercept)"],family=binomial(), offset=offset,
+        robust.binomial.prefit <- glm(cbind(y[,1],y[,2])~-1+x,family=binomial(), offset=offset,
                                       subset=(outliers!=1))
         
         
